==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/BinArray/GetUBAFree.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+8)
#define CT_v180	((void*)startLabel+32)
#define F0_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+40)
#define FN_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+68)
#define CT_v184	((void*)startLabel+120)
#define CF_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+128)
#define CT_v188	((void*)startLabel+220)
#define ST_v186	((void*)startLabel+252)
#define PP_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+276)
#define PC_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+276)
#define ST_v182	((void*)startLabel+276)
#define PP_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+303)
#define PC_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+303)
#define ST_v179	((void*)startLabel+303)
#define PS_v183	((void*)startLabel+332)
#define PS_v181	((void*)startLabel+344)
#define PS_v187	((void*)startLabel+356)
#define PS_v185	((void*)startLabel+368)
#define PS_v178	((void*)startLabel+380)
void FR_NHC_46BinArray_46hs_95getUBAFree_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node PM_NHC_46BinArray[];
extern Node PC_NHC_46Internal_46_95mkIOok1[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v180)
,	/* FN_NHC_46BinArray_46hs_95getUBAFree_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46BinArray_46hs_95getUBAFree_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90022
, useLabel(ST_v179)
,	/* CT_v180: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46BinArray_46hs_95getUBAFree_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree_35),1)
, useLabel(PS_v178)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v184)
,	/* FN_NHC_46BinArray_46hs_95getUBAFree: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v183)
, 0
, 0
, 0
, 0
, 90022
, useLabel(ST_v182)
,	/* CT_v184: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95getUBAFree: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree))
, useLabel(PS_v181)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_NHC_46BinArray_46hs_95getUBAFree_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v188)
,};
Node FN_NHC_46BinArray_46getUBAFree[] = {
  bytes2word(NEEDHEAP_I32,PUSH_ARG_I1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_N1,7,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,ZAP_ARG_I1,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v187)
, 0
, 0
, 0
, 0
, 120001
, useLabel(ST_v186)
,	/* CT_v188: (byte 0) */
  HW(1,1)
, 0
,};
Node F0_NHC_46BinArray_46getUBAFree[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46getUBAFree),1)
, useLabel(PS_v185)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree))
,};
Node PP_NHC_46BinArray_46getUBAFree[] = {
 };
Node PC_NHC_46BinArray_46getUBAFree[] = {
 	/* ST_v186: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,103,101,116)
, bytes2word(85,66,65,70)
,	/* PP_NHC_46BinArray_46hs_95getUBAFree: (byte 4) */
 	/* PC_NHC_46BinArray_46hs_95getUBAFree: (byte 4) */
 	/* ST_v182: (byte 4) */
  bytes2word(114,101,101,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(103,101,116,85)
, bytes2word(66,65,70,114)
,	/* PP_NHC_46BinArray_46hs_95getUBAFree_35: (byte 3) */
 	/* PC_NHC_46BinArray_46hs_95getUBAFree_35: (byte 3) */
 	/* ST_v179: (byte 3) */
  bytes2word(101,101,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(104,115,95,103)
, bytes2word(101,116,85,66)
, bytes2word(65,70,114,101)
, bytes2word(101,35,0,0)
,	/* PS_v183: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAFree)
, useLabel(PC_NHC_46Internal_46_95mkIOok1)
,	/* PS_v181: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAFree)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAFree)
,	/* PS_v187: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAFree)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAFree)
,	/* PS_v185: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAFree)
, useLabel(PC_NHC_46BinArray_46getUBAFree)
,	/* PS_v178: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAFree_35)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAFree_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getUBAFree" NHC.BinArray.hs_getUBAFree# 1 :: FFI.ForeignObj -> Prelude.Int */
extern HsInt hs_getUBAFree(void*);
#ifdef PROFILE
static SInfo pf_hs_getUBAFree = {"NHC.BinArray","NHC.BinArray.hs_getUBAFree#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95getUBAFree_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hs_getUBAFree(arg1);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_getUBAFree);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/BinArray/GetUBAFree.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+8)
#define CT_v184	((void*)startLabel+32)
#define F0_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+40)
#define FN_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+68)
#define CT_v188	((void*)startLabel+120)
#define CF_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+128)
#define CT_v192	((void*)startLabel+220)
#define ST_v190	((void*)startLabel+252)
#define PP_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+276)
#define PC_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+276)
#define ST_v186	((void*)startLabel+276)
#define PP_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+303)
#define PC_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+303)
#define ST_v183	((void*)startLabel+303)
#define PS_v187	((void*)startLabel+332)
#define PS_v185	((void*)startLabel+344)
#define PS_v191	((void*)startLabel+356)
#define PS_v189	((void*)startLabel+368)
#define PS_v182	((void*)startLabel+380)
void FR_NHC_46BinArray_46hs_95getUBAFree_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node PM_NHC_46BinArray[];
extern Node PC_NHC_46Internal_46_95mkIOok1[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v184)
,	/* FN_NHC_46BinArray_46hs_95getUBAFree_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46BinArray_46hs_95getUBAFree_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90001
, useLabel(ST_v183)
,	/* CT_v184: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46BinArray_46hs_95getUBAFree_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree_35),1)
, useLabel(PS_v182)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v188)
,	/* FN_NHC_46BinArray_46hs_95getUBAFree: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v187)
, 0
, 0
, 0
, 0
, 90001
, useLabel(ST_v186)
,	/* CT_v188: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95getUBAFree: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree))
, useLabel(PS_v185)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_NHC_46BinArray_46hs_95getUBAFree_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v192)
,};
Node FN_NHC_46BinArray_46getUBAFree[] = {
  bytes2word(NEEDHEAP_I32,PUSH_ARG_I1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_N1,7,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,ZAP_ARG_I1,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v191)
, 0
, 0
, 0
, 0
, 120001
, useLabel(ST_v190)
,	/* CT_v192: (byte 0) */
  HW(1,1)
, 0
,};
Node F0_NHC_46BinArray_46getUBAFree[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46getUBAFree),1)
, useLabel(PS_v189)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree))
,};
Node PP_NHC_46BinArray_46getUBAFree[] = {
 };
Node PC_NHC_46BinArray_46getUBAFree[] = {
 	/* ST_v190: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,103,101,116)
, bytes2word(85,66,65,70)
,	/* PP_NHC_46BinArray_46hs_95getUBAFree: (byte 4) */
 	/* PC_NHC_46BinArray_46hs_95getUBAFree: (byte 4) */
 	/* ST_v186: (byte 4) */
  bytes2word(114,101,101,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(103,101,116,85)
, bytes2word(66,65,70,114)
,	/* PP_NHC_46BinArray_46hs_95getUBAFree_35: (byte 3) */
 	/* PC_NHC_46BinArray_46hs_95getUBAFree_35: (byte 3) */
 	/* ST_v183: (byte 3) */
  bytes2word(101,101,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(104,115,95,103)
, bytes2word(101,116,85,66)
, bytes2word(65,70,114,101)
, bytes2word(101,35,0,0)
,	/* PS_v187: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAFree)
, useLabel(PC_NHC_46Internal_46_95mkIOok1)
,	/* PS_v185: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAFree)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAFree)
,	/* PS_v191: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAFree)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAFree)
,	/* PS_v189: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAFree)
, useLabel(PC_NHC_46BinArray_46getUBAFree)
,	/* PS_v182: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAFree_35)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAFree_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getUBAFree" NHC.BinArray.hs_getUBAFree# 1 :: FFI.ForeignObj -> Prelude.Int */
extern HsInt hs_getUBAFree(void*);
#ifdef PROFILE
static SInfo pf_NHC_46BinArray_46hs_95getUBAFree_35 = {"NHC.BinArray","NHC.BinArray.hs_getUBAFree#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95getUBAFree_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hs_getUBAFree(arg1);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46BinArray_46hs_95getUBAFree_35);
  C_RETURN(nodeptr);
}
